Query engine and processor supporting simple path and JMESPath queries with parallel bundle processing and batched output
Structs
- Output
Buffer - Processor
- Main processor for PLC bundles
- Stats
Enums
- Query
Engine - Query engine that supports both simple and JMESPath queries
Traits
Functions
- parse_
bundle_ range - Parse bundle range specification (e.g., “1-10,15,20-25”, “head”, “head~5”, “root”)
- parse_
operation_ range - Parse operation range specification (e.g., “0-999”, “3255,553,0-9”) Operations are 0-indexed global positions (0 = first operation, bundle 1 position 0)